<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="es_CO" sourcelanguage="en_US">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Automatically save documents</source>
        <translation>Guardar documentos automáticamente</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Automatically open last documents on startup</source>
        <translation>Abrir últimos documentos automáticamente al iniciar</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Restore window geometry</source>
        <translation>Restablecer geometría de la ventana</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Open external links in ReText window</source>
        <translation>Abrir enlaces externos en la ventana de ReText</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation>Extensiones de sintaxis de Markdown (separadas por coma)</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Enable synchronized scrolling for Markdown</source>
        <translation>Activar desplazamiento sincronizado para Markdown</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="169"/>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Highlight current line</source>
        <translation>Resaltar línea actual</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Show line numbers</source>
        <translation>Mostrar números de línea</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Tab key inserts spaces</source>
        <translation>La tecla Tab inserta espacios</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Tabulation width</source>
        <translation>Ancho de tabulación</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Draw vertical line at column</source>
        <translation>Dibujar línea vertical en la columna</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Icon theme name</source>
        <translation>Nombre del tema de íconos</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Stylesheet file</source>
        <translation>Archivo de hoja de estilo</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="151"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="80"/>
        <source>Using configuration file at:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Number of recent documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Default preview state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Line numbers are relative to current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Enable soft wrap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Show document stats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Hide toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Hide tabs bar when there is only one tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Show full path in window title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="170"/>
        <source>Live preview</source>
        <translation type="unfinished">Previsualizar en vivo</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="171"/>
        <source>Normal preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="../ReText/config.py" line="35"/>
        <source>(none)</source>
        <translation>(ninguno)</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="42"/>
        <source>Select file to open</source>
        <translation>Seleccione el archivo para abrir</translation>
    </message>
</context>
<context>
    <name>InsertTableDialog</name>
    <message>
        <location filename="../ReText/tabledialog.py" line="27"/>
        <source>Insert table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tabledialog.py" line="36"/>
        <source>Number of rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tabledialog.py" line="37"/>
        <source>Number of columns</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../ReText/dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Escriba el nombre del locale (por ejemplo: en_US)</translation>
    </message>
    <message>
        <location filename="../ReText/dialogs.py" line="50"/>
        <source>Set as default</source>
        <translation>Establecer como predeterminado</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="../ReText/fakevimeditor.py" line="61"/>
        <source>No write since last change (add ! to override)</source>
        <translation type="unfinished">Sin escritura desde el último cambio (agregue ! para controlar)</translation>
    </message>
    <message>
        <location filename="../ReText/fakevimeditor.py" line="118"/>
        <source>Information</source>
        <translation>Información</translation>
    </message>
</context>
<context>
    <name>ReTextEdit</name>
    <message>
        <location filename="../ReText/editor.py" line="391"/>
        <source>Save image</source>
        <translation>Guardar imagen</translation>
    </message>
    <message>
        <location filename="../ReText/editor.py" line="391"/>
        <source>Images (*.png *.jpg)</source>
        <translation>Imágenes (*.png *.jpg)</translation>
    </message>
    <message>
        <location filename="../ReText/editor.py" line="212"/>
        <source>Add to dictionary</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="../ReText/tab.py" line="184"/>
        <source>New document</source>
        <translation>Documento nuevo</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="189"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>No se pudo leer el contenido del archivo, ¡revise si tiene instalado el &lt;a href=&quot;%s&quot;&gt;módulo necesario&lt;/a&gt;!</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="478"/>
        <source>Create missing file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="478"/>
        <source>The file &apos;%s&apos; does not exist.

Do you want to create it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="511"/>
        <source>File could not be created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="511"/>
        <source>Could not create file &apos;%s&apos;: %s</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="../ReText/window.py" line="82"/>
        <source>File toolbar</source>
        <translation>Barra de herramientas de archivo</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="84"/>
        <source>Edit toolbar</source>
        <translation>Barra de herramientas de edición</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="86"/>
        <source>Search toolbar</source>
        <translation>Barra de herramientas de búsqueda</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="90"/>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="93"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="96"/>
        <source>Set encoding</source>
        <translation>Establecer codificación de caracteres</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1190"/>
        <source>Reload</source>
        <translation>Recargar</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="102"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="106"/>
        <source>Save as</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="108"/>
        <source>Next tab</source>
        <translation>Pestaña siguiente</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="110"/>
        <source>Previous tab</source>
        <translation>Pestaña anterior</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="114"/>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="117"/>
        <source>Print preview</source>
        <translation>Vista previa de impresión</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="119"/>
        <source>View HTML code</source>
        <translation>Ver código HTML</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="120"/>
        <source>Change editor font</source>
        <translation>Cambiar letra del editor</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="122"/>
        <source>Change preview font</source>
        <translation>Cambiar letra de la vista previa</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="124"/>
        <source>Find text</source>
        <translation>Buscar texto</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="129"/>
        <source>Preview</source>
        <translation>Vista previa</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="139"/>
        <source>Live preview</source>
        <translation>Previsualizar en vivo</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="146"/>
        <source>Table editing mode</source>
        <translation>Modo de edición de tablas</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="152"/>
        <source>FakeVim mode</source>
        <translation>Modo FaveVim</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="157"/>
        <source>Fullscreen mode</source>
        <translation>Modo pantalla completa</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="630"/>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="168"/>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="171"/>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="173"/>
        <source>Redo</source>
        <translation>Rehacer</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="175"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="177"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="179"/>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="195"/>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="196"/>
        <source>Set locale</source>
        <translation>Establecer locale</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="197"/>
        <source>Use WebKit renderer</source>
        <translation>Usar renderizador WebKit</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="207"/>
        <source>Show directory</source>
        <translation>Mostrar directorio</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="208"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="210"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="212"/>
        <source>Replace</source>
        <translation>Reemplazar</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="214"/>
        <source>Replace all</source>
        <translation>Reemplazar todo</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="218"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="222"/>
        <source>Get help online</source>
        <translation>Obtener ayuda en línea</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="223"/>
        <source>About ReText</source>
        <translation>Sobre ReText</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="226"/>
        <source>About Qt</source>
        <translation>Sobre Qt</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="241"/>
        <source>Bold</source>
        <translation>Negrita</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="243"/>
        <source>Italic</source>
        <translation>Cursiva</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="245"/>
        <source>Underline</source>
        <translation>Subrayado</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="318"/>
        <source>Formatting</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="258"/>
        <source>Symbols</source>
        <translation>Símbolos</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="263"/>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="264"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="265"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="268"/>
        <source>Open recent</source>
        <translation>Abrir reciente</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="281"/>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="306"/>
        <source>Spell check</source>
        <translation>Revisar ortografía</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="315"/>
        <source>Default markup</source>
        <translation>Marcado predeterminado</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="360"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="363"/>
        <source>Replace with</source>
        <translation>Reemplazar por</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="365"/>
        <source>Case sensitively</source>
        <translation>Tener en cuenta mayúsculas y minúsculas</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="526"/>
        <source>New document</source>
        <translation>Documento nuevo</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="714"/>
        <source>Please, save the file somewhere.</source>
        <translation>Guarde el archivo en algún lugar.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="830"/>
        <source>Select one or several files to open</source>
        <translation>Seleccione uno o varios archivos para abrir</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1248"/>
        <source>Supported files</source>
        <translation>Archivos admitidos</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1248"/>
        <source>All files (*)</source>
        <translation>Todos los archivos (*)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="869"/>
        <source>Select file encoding from the list:</source>
        <translation>Seleccione una codificación de caracteres de la lista:</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="892"/>
        <source>Plain text (*.txt)</source>
        <translation>Texto plano (*.txt)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="895"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s archivos</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="970"/>
        <source>Save file</source>
        <translation>Guardar archivo</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="915"/>
        <source>Cannot save to file which is open in another tab!</source>
        <translation>¡No se puede guardar a un archivo que ya está abierto en otra pestaña!</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="938"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>¡No se puede guardar el archivo porque es de solo lectura!</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="960"/>
        <source>Export document to ODT</source>
        <translation>Exportar documento a ODT</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="960"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>Archivos OpenDocument (*.odt)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="970"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>Archivos HTML (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1019"/>
        <source>Export document to PDF</source>
        <translation>Exportar documento a PDF</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1019"/>
        <source>PDF files (*.pdf)</source>
        <translation>Archivos PDF (*.pdf)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1046"/>
        <source>Print document</source>
        <translation>Imprimir documento</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1069"/>
        <source>Export document</source>
        <translation>Exportar documento</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1090"/>
        <source>Failed to execute the command:</source>
        <translation>No se pudo ejecutar la orden:</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1131"/>
        <source>Alt text</source>
        <translation>Texto alternativo</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1132"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1132"/>
        <source>Link text</source>
        <translation>Texto del enlace</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1173"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation>Otra aplicación borró este archivo.
Asegúrese de guardar el archivo antes de salir.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1181"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation>Otra aplicación modificó este documento.
¿Quiere recargar el archivo (esto eliminará los cambios que usted haya hecho)?</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1186"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation>Si elige no recargar el archivo, el modo de guardado automático se va a desactivar durante esta sesión para evitar pérdida de datos.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1210"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>El documento fue modificado.
¿Quiere guardar los cambios?</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1238"/>
        <source>HTML code</source>
        <translation>Código HTML</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation>ReText %s (usando PyMarkups %s)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Editor sencillo pero poderoso para Markdown y reStructuredText</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Autor: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Website</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Markdown syntax</source>
        <translation>Sintaxis de Markdown</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>reStructuredText syntax</source>
        <translation>Sintaxis de reStructuredText</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="202"/>
        <source>Use WebEngine (Chromium) renderer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="112"/>
        <source>Close tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="678"/>
        <source>Go to line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="144"/>
        <source>Insert table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="149"/>
        <source>Insert images by file path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="181"/>
        <source>Paste image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="183"/>
        <source>Move line up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="185"/>
        <source>Move line down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="678"/>
        <source>Type the line number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="993"/>
        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1248"/>
        <source>Select one or several images to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextInfoArea</name>
    <message>
        <location filename="../ReText/editor.py" line="582"/>
        <source>%d w | %d a | %d c</source>
        <comment>count of words, alphanumeric characters, all characters</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../ReText/__main__.py" line="77"/>
        <source>Open the files in preview mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/__main__.py" line="79"/>
        <source>Create a new window even if there is an existing one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/__main__.py" line="83"/>
        <source>List of files to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
